# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Note: BR: perl(LWP::Protocol::https) & perl(Test::Pod::No404s) (from F-17) dropped
# due to making builds dependent on unreliable external services like rt.cpan.org

Name:		perl-Package-DeprecationManager
Version:	0.18
Release:	2.%{__distinit}%{__distvers}
Summary:	Manage deprecation warnings for your distribution
License:	Artistic-2.0
URL:		https://metacpan.org/release/Package-DeprecationManager
Source0:	https://cpan.metacpan.org/modules/by-module/Package/Package-DeprecationManager-%{version}.tar.gz
Patch3:		Package-DeprecationManager-0.18-stopwords.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(List::Util) >= 1.33
BuildRequires:	perl(Package::Stash)
BuildRequires:	perl(Params::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Install)
BuildRequires:	perl(Sub::Util)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More) >= 0.96
BuildRequires:	perl(Test::Warnings)
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
%if 0%{!?perl_bootstrap:1}
# Author Tests
BuildRequires:	perl(blib)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::Mojibake)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling), hunspell-en
BuildRequires:	perl(Test::Version) >= 1.002
# Release Tests
BuildRequires:	perl(Test::CPAN::Changes) >= 0.19
BuildRequires:	perl(Test::CPAN::Meta::JSON)
%if 0%{?fedora} > 17
BuildRequires:	perl(Test::Pod::LinkCheck)
%endif
%endif
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module allows you to manage a set of deprecations for one or more modules.

When you import Package::DeprecationManager, you must provide a set of
-deprecations as a hash ref. The keys are "feature" names, and the values are
the version when that feature was deprecated.

%prep
%setup -q -n Package-DeprecationManager-%{version}

# Some extra stopwords for old hunspell versions
%patch -P 3

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

# We don't have precious lint, so skip that test
%if 0%{!?perl_bootstrap:1}
make test TEST_FILES="$(echo $(find xt/ -name '*.t' | grep -Fv precious.t))"
%endif

%files
%license LICENSE
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTING.md README.md
%{perl_vendorlib}/Package/
%{_mandir}/man3/Package::DeprecationManager.3*

%changelog
* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 0.18-2
- Avoid use of deprecated patch syntax

* Mon Feb 20 2023 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18
  - Use Sub::Util instead of Sub::Name, which is part of Scalar-List-Utils,
    which itself is already a dependency (GH#3)
- Use SPDX-format license tag
- Use %%license unconditionally
- Package CODE_OF_CONDUCT.md
- Drop support for building with List::Util < 1.33 since we require Sub::Util,
  which became available at the same time as List::Util 1.33

* Fri Jun  7 2019 Paul Howarth <paul@city-fan.org> - 0.17-9
- Perl 5.30 rebuild

* Thu Apr 19 2018 Paul Howarth <paul@city-fan.org> - 0.17-5
- BR: perl(LWP::Protocol::https) & perl(Test::Pod::No404s) dropped due to
  making builds dependent on unreliable external services like rt.cpan.org
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.96
  - Test::Warnings always available
  - Spell checker back-end is always hunspell

* Mon Jan  9 2017 Paul Howarth <paul@city-fan.org> - 0.17-2
- Test::Warnings now available back to Fedora 9
- Fix FTBFS when perl is not in the minimal buildroot

* Mon Jun 20 2016 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Remove use of namespace::autoclean
- BR: perl-generators where available
- Simplify find command using -delete
- Update patches as needed
- Author and Release Tests moved to xt/

* Tue Mar 22 2016 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
  - The subs installed into the caller are now named with Sub::Name; this makes
    these subs appear to be part of the caller, as opposed to an import, which
    is what we want, since each installed sub is constructed uniquely for a
    given package
- Update patches as needed

* Sat Nov 14 2015 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Made this module co-operate with existing import() subs in packages that
    use this module, as long as you use this module last
- Update patches as needed
- Bundle Test::More and Test::Warnings for use with old distributions

* Sat Jun 27 2015 Paul Howarth <paul@city-fan.org> - 0.14-4
- Perl 5.22 rebuild

* Tue Apr 21 2015 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Use any() from List::Util 1.33+ instead of List::MoreUtils
- Add patch to use List::MoreUtils::any() on old distributions where we don't
  have List::Util 1.33+
- Add patch to support building without Test::Code::TidyAll
- Classify buildreqs by usage
- Update patches as needed

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 0.13-11
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Drop %%defattr, redundant since rpm 4.4
- BR: perl(Test::CPAN::Changes) and perl(Test::Requires) unconditionally
- Use %%license where possible

* Thu Jan 16 2014 Paul Howarth <paul@city-fan.org> - 0.13-6
- Don't run the release tests when bootstrapping

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 0.13-5
- Specify version requirements for perl(Test::Output), perl(Test::Pod) and
  perl(Test::Pod::Coverage)

* Mon Apr 23 2012 Paul Howarth <paul@city-fan.org> - 0.13-2
- Upstream has dropped Kwalitee test, so drop BR: perl(Test::Kwalitee)

* Fri Mar  9 2012 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Fix dist.ini to not add Test::Spelling as a requirement

* Mon Mar  5 2012 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12
  - Fix tests to pass with Carp 1.25 (CPAN RT#75520)
- BR: perl(Test::Spelling), aspell-en
- Add patch to accept "deprecations" as a valid dictionary word
- Update patches to apply cleanly
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.11-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Jun 20 2011 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11
  - Allow an empty hash for the -deprecations parameter
- BR: perl(ExtUtils::MakeMaker)
- BR: perl(Test::CPAN::Changes)
- Update patches for old ExtUtils::MakeMaker and Test::More compatibility

* Tue Mar 22 2011 Paul Howarth <paul@city-fan.org> - 0.10-2
- Unconditionally BR: perl(Test::Kwalitee)
- Nobody else likes macros for commands

* Wed Oct 27 2010 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10
  - Use Test::Fatal rather than Test::Exception in test suite
- Update patches for old Test::More and no Test::Requires

* Mon Oct 18 2010 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
  - Added a compilation test

* Fri Oct 15 2010 Paul Howarth <paul@city-fan.org> - 0.08-1
- Update to 0.08
  - The use of regular expressions in ignores didn't really work in 0.06
  - Added missing deps on List::MoreUtils and Test::Requires
  - Replaced Test::Warn with Test::Output in the tests
  - Made the tests actually test what they should be testing
- BR: Test::Output rather than Test::Warn
- Update patches

* Fri Oct 15 2010 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06
  - Removed hard dep on Test::Warn for the benefit of Moose
  - Fixed what looked like a bug in -ignore handling
  - The -ignore parameter now accepts regexes as well as package names
- Update compatibility patches
- BR: List::MoreUtils
- BR: Test::Requires where possible, patch it out elsewhere

* Mon Jul 26 2010 Paul Howarth <paul@city-fan.org> - 0.04-1
- Initial RPM version
